package LibStorage::MdInfo;
BEGIN {
    %TYPEINFO = (
        ALL_METHODS => 0,
        new => ["function", "any", "string"],
        swig_v_get => ["function", "any", "any"],
        swig_v_set => ["function", "void", "any", "any"],
        swig_nr_get => ["function", "integer", "any"],
        swig_nr_set => ["function", "void", "any", "integer"],
        swig_type_get => ["function", "integer", "any"],
        swig_type_set => ["function", "void", "any", "integer"],
        swig_parity_get => ["function", "integer", "any"],
        swig_parity_set => ["function", "void", "any", "integer"],
        swig_uuid_get => ["function", "string", "any"],
        swig_uuid_set => ["function", "void", "any", "string"],
        swig_sb_ver_get => ["function", "string", "any"],
        swig_sb_ver_set => ["function", "void", "any", "string"],
        swig_chunkSizeK_get => ["function", "integer", "any"],
        swig_chunkSizeK_set => ["function", "void", "any", "integer"],
        swig_devices_get => ["function", "string", "any"],
        swig_devices_set => ["function", "void", "any", "string"],
        swig_spares_get => ["function", "string", "any"],
        swig_spares_set => ["function", "void", "any", "string"],
    );
}

1;
